Справочник социальных статусов
Идентификатор	Описание
1	Служащий
2	Рабочий
3	Работник сельского хозяйства
4	Пенсионер
5	Учащийся
6	Домохозяйка
7	Лицо, занят.индивид.трудом
8	Служитель культа
9	Безработный
10	Прочее
11	Сотрудник компании
12	Член семьи